@@ -20,7 +20,7 @@ and integration into the Python ecosystem of tools for data analysis and
 scientific computation.
 
 
-Usage examples can be found on http://nbviewer.ipython.org/urls/networkit.iti.kit.edu/data/uploads/docs/NetworKit_UserGuide.ipynb
+Usage examples can be found on http://nbviewer.ipython.org/urls/networkit.github.io/data/uploads/docs/NetworKit_UserGuide.ipynb
 """
 
 __author__ = "Christian Staudt"
@@ -29,7 +29,7 @@ __credits__ = ["Eugenio Angriman", "Lukas Barth", "Miriam Beddig", "Elisabetta B
 	"Guido Brückner", "Mark Erb",  "Kolja Esders", "Patrick Flick", "Michael Hamann", "Lukas Hartmann", "Daniel Hoske", "Gerd Lindner", "Moritz v. Looz", "Yassine Marrakchi", "Henning Meyerhenke", \
 	"Manuel Penschuck", "Marcel Radermacher", "Klara Reichard", "Marvin Ritter", "Aleksejs Sazonovs", "Hung Tran", "Florian Weber", "Michael Wegner", "Jörg Weisbarth", "Kolja Esders"]
 __license__ = "MIT"
-__version__ = "4.6"
+__version__ = "5.0"
 
 # standard library modules
 import csv
@@ -37,6 +37,12 @@ import os
 import logging
 import sys
 
+# pyplot might not be available in non-interactive environments.
+try:
+	import matplotlib.pyplot as _pyplot
+except ImportError as importError:
+	_pyplot = None
+
 # local imports
 from . import stopwatch
 from . import graph
@@ -54,7 +60,6 @@ from . import partitioning
 from . import coloring
 from . import workflows
 from . import flow
-from . import plot
 from . import sparsification
 from . import scd
 from . import clique
@@ -68,15 +73,18 @@ from . import stats
 from . import sampling
 from . import viz
 from . import randomization
-from .profiling import profiling
+
+if _pyplot is not None:
+	from . import plot
+	from .profiling import profiling
+else:
+	print("WARNING: pyplot is not available; some functionality is disabled", file=sys.stderr)
 
 try:
 	from . import viztasks
 except ImportError as importError:
-	print(
-		"""WARNING: some dependencies are not satisfied which are needed to use the
-		'viztasks' submodule""")
-	print(importError)
+	print("WARNING: some dependencies are not satisfied"
+			" which are needed to use the 'viztasks' submodule", file=sys.stderr)
 
 #--------- Top Level Classes and Functions ----------------#
 #
