@@ -6,6 +6,7 @@
  */
 
 #include "DenseMatrix.h"
+#include <algorithm>
 
 namespace NetworKit {
 
@@ -23,7 +24,7 @@ DenseMatrix::DenseMatrix(const count dimension, const std::vector<Triplet>& trip
 
 DenseMatrix::DenseMatrix(const count nRows, const count nCols, const std::vector<Triplet>& triplets, const double zero) : nRows(nRows), nCols(nCols), entries(nRows*nCols, zero), zero(zero) {
 #pragma omp parallel for
-	for (index k = 0; k < triplets.size(); ++k) {
+	for (omp_index k = 0; k < static_cast<omp_index>(triplets.size()); ++k) {
 		entries[triplets[k].row * nCols + triplets[k].column] = triplets[k].value;
 	}
 }
@@ -60,7 +61,7 @@ Vector DenseMatrix::row(const index i) const {
 	Vector row(numberOfColumns(), zero, true);
 	index offset = i * numberOfColumns();
 #pragma omp parallel for
-	for (index j = 0; j < numberOfColumns(); ++j) {
+	for (omp_index j = 0; j < static_cast<omp_index>(numberOfColumns()); ++j) {
 		row[j] = entries[offset + j];
 	}
 
@@ -70,7 +71,7 @@ Vector DenseMatrix::row(const index i) const {
 Vector DenseMatrix::column(const index j) const {
 	Vector column(numberOfRows(), zero);
 #pragma omp parallel for
-	for (index i = 0; i < numberOfRows(); ++i) {
+	for (omp_index i = 0; i < static_cast<omp_index>(numberOfRows()); ++i) {
 		column[i] = entries[i * numberOfColumns() + j];
 	}
 
@@ -80,7 +81,7 @@ Vector DenseMatrix::column(const index j) const {
 Vector DenseMatrix::diagonal() const {
 	Vector diagonal(std::min(numberOfRows(), numberOfColumns()), zero);
 #pragma omp parallel for
-	for (index i = 0; i < diagonal.getDimension(); ++i) {
+	for (omp_index i = 0; i < static_cast<omp_index>(diagonal.getDimension()); ++i) {
 		diagonal[i] = (*this)(i,i);
 	}
 
@@ -115,7 +116,7 @@ DenseMatrix DenseMatrix::operator*(const double &scalar) const {
 
 DenseMatrix& DenseMatrix::operator*=(const double &scalar) {
 #pragma omp parallel for
-	for (index k = 0; k < entries.size(); ++k) {
+	for (omp_index k = 0; k < static_cast<omp_index>(entries.size()); ++k) {
 		entries[k] *= scalar;
 	}
 
@@ -128,7 +129,7 @@ Vector DenseMatrix::operator*(const Vector &vector) const {
 
 	Vector result(numberOfRows(), zero);
 #pragma omp parallel for
-	for (index i = 0; i < numberOfRows(); ++i) {
+	for (omp_index i = 0; i < static_cast<omp_index>(numberOfRows()); ++i) {
 		index offset = i * numberOfColumns();
 		for (index k = offset, j = 0; k < offset + numberOfColumns(); ++k, ++j) {
 			result[i] += entries[k] * vector[j];
@@ -143,7 +144,7 @@ DenseMatrix DenseMatrix::operator*(const DenseMatrix &other) const {
 	std::vector<double> resultEntries(numberOfRows() * other.numberOfColumns());
 
 #pragma omp parallel for
-	for (index i = 0; i < numberOfRows(); ++i) {
+	for (omp_index i = 0; i < static_cast<omp_index>(numberOfRows()); ++i) {
 		index offset = i * other.numberOfColumns();
 		for (index k = 0; k < numberOfColumns(); ++k) {
 			double val_i_k = (*this)(i,k);
