@@ -56,6 +56,22 @@ inline std::vector<std::string> split(const std::string& s, char delim = ' ') {
 	return split(s.begin(), s.end(), delim);
 }
 
+/**
+ * Determines whether @a str ends with @a suffix.
+ */
+inline bool ends_with(const std::string& str, const std::string& suffix) {
+    return str.size() >= suffix.size() &&
+           str.compare(str.size() - suffix.size(), suffix.size(), suffix) == 0;
+}
+
+/**
+ * Determines whether @a str starts with @a prefix.
+ */
+inline bool starts_with(const std::string& str, const std::string& prefix) {
+    return str.size() >= prefix.size() &&
+           str.compare(0, prefix.size(), prefix) == 0;
+}
+
 } /* namespace StringTools */
 } /* namespace Aux */
 #endif /* STRINGTOOLS_H_ */
