@@ -45,7 +45,7 @@ void ApproxGroupBetweenness::run() {
 	hasSortedGroup = false;
 
 #pragma omp parallel for
-	for (count l = 0; l < samples; ++l) {
+	for (omp_index l = 0; l < static_cast<omp_index>(samples); ++l) {
 		node s = G.randomNode();
 		node t;
 		do {
@@ -70,7 +70,8 @@ void ApproxGroupBetweenness::run() {
 
 		// Insert the HyperEdge into hyperEdgePerSample
 		for (auto n : newHyperEdge) {
-			hyperEdgesPerSample[l].push_back(n);
+			if(n != s && n != t)
+				hyperEdgesPerSample[l].push_back(n);
 		}
 	}
 
