@@ -29,9 +29,7 @@ std::vector<node> GraphCoarsening::getFineToCoarseNodeMapping() const {
 
 
 std::map<node, std::vector<node> > GraphCoarsening::getCoarseToFineNodeMapping() const {
-	if (!hasRun) {
-		throw std::runtime_error("Call run()-method first.");
-	}
+	assureFinished();
 
 	std::map<node, std::vector<node>> reverseMap;
 	Gcoarsened.forNodes([&](node v_){
