@@ -16,7 +16,7 @@ namespace NetworKit {
  * @ingroup community
  * A parallel agglomerative community detection algorithm, maximizing modularity.
  */
-class ParallelAgglomerativeClusterer: public NetworKit::CommunityDetectionAlgorithm {
+class ParallelAgglomerativeClusterer: public CommunityDetectionAlgorithm {
 
 public:
 	/**
