@@ -26,7 +26,7 @@ void AlgebraicDistance::randomInit() {
 	loads.resize(numSystems*G.upperNodeIdBound());
 
 	#pragma omp parallel for
-	for (index i = 0; i < loads.size(); ++i) {
+	for (omp_index i = 0; i < static_cast<omp_index>(loads.size()); ++i) {
 		loads[i] = Aux::Random::real();
 	}
 }
