@@ -10,27 +10,6 @@ namespace NetworKit {
 
 RandomMaximumSpanningForest::RandomMaximumSpanningForest(const Graph &G) : G(G), hasWeightedEdges(false), hasMSF(false), hasAttribute(false) { };
 
-template <typename A>
-RandomMaximumSpanningForest::RandomMaximumSpanningForest(const Graph &G, const std::vector< A > &attribute) : G(G), hasWeightedEdges(false), hasMSF(false), hasAttribute(false) {
-	if (!G.hasEdgeIds()) {
-		throw std::runtime_error("Error: Edges of G must be indexed for using edge attributes");
-	}
-
-	weightedEdges.reserve(G.numberOfEdges());
-
-	G.forEdges([&](node u, node v, edgeid eid) {
-		weightedEdges.emplace_back(u, v, attribute[eid], eid);
-	});
-
-	INFO(weightedEdges.size(), " weighted edges saved");
-
-	hasWeightedEdges = true;
-}
-
-// instantiate for count and edgeweight
-template RandomMaximumSpanningForest::RandomMaximumSpanningForest<edgeweight>(const Graph &G, const std::vector<edgeweight>&);
-template RandomMaximumSpanningForest::RandomMaximumSpanningForest<count>(const Graph &G, const std::vector<count>&);
-
 void RandomMaximumSpanningForest::run() {
 	hasRun = false;
 	hasMSF = false;
