@@ -14,9 +14,11 @@ namespace NetworKit {
 
 /**
  * @ingroup independentset
+ * DEPRECATED: put into code archive, nobody seems to be using it
  * Abstract base class for independent set algorithms.
  */
-class IndependentSetFinder {
+class [[deprecated]]
+IndependentSetFinder {
 
 
 public:
