@@ -3,7 +3,7 @@
 
 namespace NetworKit {
 
-void NetworKit::CoverWriter::write(Cover& zeta, const std::string& path) const {
+void CoverWriter::write(Cover& zeta, const std::string& path) const {
 	std::ofstream file{path};
 
 	std::vector<std::vector<index> > sets(zeta.upperBound());
