@@ -20,6 +20,8 @@ EdgeListReader::EdgeListReader(const char separator, const node firstNode, const
 }
 
 Graph EdgeListReader::read(const std::string& path) {
+	this->mapNodeIds.clear();
+
 	if (this->continuous) {
 		DEBUG("read graph with continuous ids");
 		return readContinuous(path);
@@ -104,6 +106,7 @@ Graph EdgeListReader::readContinuous(const std::string& path) {
 	// split the line into start and end node. since the edges are sorted, the start node has the highest id of all nodes
 	i = 0; // count lines
 	while(std::getline(file,line)){
+		if (line.empty()) continue;
 		if(*line.rbegin() == '\r') line.pop_back();
 		++i;
 		if (line.compare(0, this->commentPrefix.length(), this->commentPrefix) == 0) {
@@ -201,6 +204,7 @@ Graph EdgeListReader::readNonContinuous(const std::string& path) {
 	// split the line into start and end node. since the edges are sorted, the start node has the highest id of all nodes
 	i = 0; // count lines
 	while(std::getline(file,line)){
+		if (line.empty()) continue;
 		if(*line.rbegin() == '\r') line.pop_back();
         ++i;
 		if (line.compare(0, this->commentPrefix.length(), this->commentPrefix) == 0) {
