@@ -17,11 +17,11 @@
 namespace NetworKit {
 
 /**
- * A writer for the edge list format used by the LFR benchmark generators, defined as:
- * 		list of edges (nodes are labelled from 1 to the number of nodes;
- * 		the edges are ordered and repeated twice, i.e. source-target and target-source).
+ * @ingroup io
+ * A writer for the edge list format. The output will contain one edge per line,
+ * in the format fromNodeSEPARATORtoNode, where separator can be specified by
+ * the user.
  *
- * 	The starting index is a parameter to enable other edge list formats.
  */
 class EdgeListWriter {
 
@@ -32,8 +32,9 @@ public:
 	/**
 	 * @param[in]	separator	character used to separate nodes in an edge line
 	 * @param[in]	firstNode	index of the first node in the file
+	 * @param[in]	bothDirections	for undirected graphs: if every edge shall be written in both directions (default: false)
 	 */
-	EdgeListWriter(char separator, node firstNode);
+	EdgeListWriter(char separator, node firstNode, bool bothDirections = false);
 
 	/**
 	 * Write the graph to a file.
@@ -46,6 +47,7 @@ protected:
 
 	char separator; 	//!< character separating nodes in an edge line
 	node firstNode;
+	bool bothDirections;
 };
 
 } /* namespace NetworKit */
