@@ -17,7 +17,7 @@ namespace NetworKit {
 /**
  * @ingroup io
  */
-class METISGraphWriter: public NetworKit::GraphWriter {
+class METISGraphWriter: public GraphWriter {
 
 public:
 
