@@ -12,13 +12,10 @@
 #include <vector>
 #include <string>
 #include <tuple>
+#include "../Globals.h"
 
 namespace NetworKit {
 
-typedef uint64_t index;
-typedef index node;
-typedef uint64_t count;
-
 /**
  * @ingroup io
  * Parser for the METIS file format.
