@@ -5,6 +5,9 @@
  *      Author: Kolja Esders (kolja.esders@student.kit.edu)
  */
 
+#include <algorithm>
+#include <numeric>
+
 #include "EvaluationMetric.h"
 #include "PredictionsSorter.h"
 #include "../auxiliary/Parallel.h"
@@ -148,7 +151,7 @@ void EvaluationMetric::setTrueAndFalseNegatives() {
 void EvaluationMetric::setPositivesAndNegatives() {
   numPositives = 0;
   #pragma omp parallel for
-  for (index i = 0; i < predictions.size(); ++i) {
+  for (omp_index i = 0; i < static_cast<omp_index>(predictions.size()); ++i) {
     if (testGraph->hasEdge(predictions[i].first.first, predictions[i].first.second)) {
       #pragma omp atomic
       numPositives++;
