@@ -18,4 +18,7 @@ void PredictionsSorter::sortByNodePair(std::vector<LinkPredictor::prediction>& p
   Aux::Parallel::sort(predictions.begin(), predictions.end(), ConcreteNodePairComp);
 }
 
-} // namespace NetworKit
\ No newline at end of file
+PredictionsSorter::ScoreComp PredictionsSorter::ConcreteScoreComp{};
+PredictionsSorter::NodePairComp PredictionsSorter::ConcreteNodePairComp{};
+
+} // namespace NetworKit
