@@ -9,6 +9,8 @@
 #define MATCHER_H_
 
 #include "Matching.h"
+#include "../base/Algorithm.h"
+
 
 namespace NetworKit {
 
@@ -16,10 +18,12 @@ namespace NetworKit {
  * @ingroup matching
  * Abstract base class for matching algorithms.
  */
-class Matcher {
+class Matcher : public Algorithm {
 protected:
 	const Graph& G;
 	Matching M;
+	bool edgeScoresAsWeights;	//<! if true, algorithm should use edge scores instead of edge weights
+	const std::vector<double> edgeScores; 	//<! optional edge scores to be used instead of edge weight
 
 public:
 	/**
@@ -28,9 +32,17 @@ public:
 	 */
 	Matcher(const Graph& G);
 
+	/**
+	 * Constructor.
+	 * @param[in] G Graph for which matching is to be computed.
+	 * @param edgeScores 	(optional) to be used instead of weights
+	 */
+	Matcher(const Graph& G, const std::vector<double>& edgeScores);
+
 	/** Default destructor */
 	virtual ~Matcher() = default;
 
+
 	/**
 	 * Run the matching algorithm on the stored graph and return a matching.
 	 * @return A matching of the stored graph.
