@@ -18,7 +18,7 @@ namespace NetworKit {
  * @ingroup overlap
  * Determines the overlap of multiple partitions by hashing partition identifiers.
  */
-class HashingOverlapper: public NetworKit::Overlapper {
+class HashingOverlapper: public Overlapper {
 
 public:
 
