@@ -22,7 +22,7 @@ namespace CurveballDetails { struct CurveballIM; }
 class Curveball : public Algorithm {
 public:
 
-	explicit Curveball(const NetworKit::Graph &G);
+	explicit Curveball(const Graph &G);
 
 	virtual ~Curveball();
 
@@ -36,7 +36,7 @@ public:
 
 	virtual std::string toString() const override final;
 
-	virtual bool isParallel() const {
+	virtual bool isParallel() const override final {
 		return false;
 	}
 
