@@ -12,7 +12,7 @@
 
 namespace NetworKit {
 
-GlobalCurveball::GlobalCurveball(const NetworKit::Graph &G,
+GlobalCurveball::GlobalCurveball(const Graph &G,
                                  unsigned number_of_global_trades) :
     impl(new CurveballDetails::GlobalCurveballImpl{G}),
     numGlobalTrades{number_of_global_trades}
@@ -43,7 +43,7 @@ void GlobalCurveball::run() {
 }
 
 Graph GlobalCurveball::getGraph() {
-    if (!hasRun) throw std::runtime_error("Call run method first");
+    assureFinished();
     return impl->getGraph();
 }
 
@@ -51,4 +51,4 @@ std::string GlobalCurveball::toString() const  {
     return "GlobalCurveball";
 }
 
-}
\ No newline at end of file
+}
