@@ -231,7 +231,8 @@ class Profile:
 		""" creates a profile object
 
 		Args:
-			G: graph to profile
+			G: networkit.Graph
+				Graph to profile
 			preset: name of preset configuration: "complete", "minimal", "default"
 			config: object to control some aspects of the generation behaviour (Config)
 		Returns:
@@ -279,7 +280,7 @@ class Profile:
 			("Centrality.Betweenness", 				"Node Centrality",	"Betweenness",
 				True,	funcScores,	"Score",				centrality.ApproxBetweenness2,			(G, 10, True)),
 			("Centrality.Closeness",				"Node Centrality",	"Closeness",
-				True,	funcScores,	"Score",				centrality.ApproxCloseness,				(G, 10, True)),
+				True,	funcScores,	"Score",				centrality.ApproxCloseness,				(G, min(10, G.numberOfNodes()), True)),
 			("Partition.Communities", 				"Partition",		"Communities",
 				False,	funcSizes,	"Nodes per Community",	community.PLM,			 				(G, )),
 			("Partition.ConnectedComponents", 		"Partition",		"Connected Components",
@@ -754,7 +755,7 @@ class Profile:
 			try:
 				timerInstance = stopwatch.Timer()
 				self.verbosePrint("EffectiveDiameter: ", end="")
-				diam = distance.ApproxEffectiveDiameter(self.__G)
+				diam = distance.EffectiveDiameterApproximation(self.__G)
 				diameter = diam.run().getEffectiveDiameter()
 				elapsedMain = timerInstance.elapsed
 				self.verbosePrint("{:.2F} s".format(elapsedMain))
